@@ -7,9 +7,10 @@ from pyimporters_csv.csv import CSVKnowledgeParser, CSVOptions, CSVOptionsModel
 
 
 def test_csv():
-    source = Path('data/Digestion.csv')
+    testdir = Path(__file__).parent
+    source = Path(testdir, 'data/Digestion.csv')
     parser = CSVKnowledgeParser()
-    options = CSVOptionsModel(encoding="utf-8", identifier_col="ID", prefLabel_col="prefLabel_en", altLabel_cols="altLabel_en", multivalue_separator="|")
+    options = CSVOptionsModel(encoding="utf-8", identifier_col="ID", preferredForm_col="prefLabel_en", altForms_cols="altLabel_en", multivalue_separator="|")
     concepts = list(parser.parse(source, options.dict(), Bar('Processing')))
     assert len(concepts) == 92
     c7 : Term = concepts[7]
