@@ -7,9 +7,10 @@ from pyimporters_csv.excel import ExcelKnowledgeParser, ExcelOptionsModel
 
 
 def test_xls():
-    source = Path('data/Digestion.xls')
+    testdir = Path(__file__).parent
+    source = Path(testdir, 'data/Digestion.xls')
     parser = ExcelKnowledgeParser()
-    options = ExcelOptionsModel(encoding="utf-8", identifier_col="ID", prefLabel_col="prefLabel_en", altLabel_cols="altLabel_en", multivalue_separator="|")
+    options = ExcelOptionsModel(encoding="utf-8", identifier_col="ID", preferredForm_col="prefLabel_en", altForms_cols="altLabel_en", multivalue_separator="|")
     concepts = list(parser.parse(source, options.dict(), Bar('Processing')))
     assert len(concepts) == 92
     c7 : Term = concepts[7]
@@ -19,9 +20,10 @@ def test_xls():
     assert set(c7.properties['altForms']) == set(['SPF animal', 'specific pathogen free animal'])
 
 def test_xlsx():
-    source = Path('data/Digestion.xlsx')
+    testdir = Path(__file__).parent
+    source = Path(testdir, 'data/Digestion.xlsx')
     parser = ExcelKnowledgeParser()
-    options = ExcelOptionsModel(encoding="utf-8", identifier_col="ID", prefLabel_col="prefLabel_en", altLabel_cols="altLabel_en", multivalue_separator="|")
+    options = ExcelOptionsModel(encoding="utf-8", identifier_col="ID", preferredForm_col="prefLabel_en", altForms_cols="altLabel_en", multivalue_separator="|")
     concepts = list(parser.parse(source, options.dict(), Bar('Processing')))
     assert len(concepts) == 92
     c7 : Term = concepts[7]
