@@ -7,7 +7,8 @@ from pyimporters_csv.text import TXTKnowledgeParser, TXTOptionsModel
 
 
 def test_text():
-    source = Path('data/currencies.txt')
+    testdir = Path(__file__).parent
+    source = Path(testdir, 'data/currencies.txt')
     parser = TXTKnowledgeParser()
     options = TXTOptionsModel(encoding="utf-8")
     concepts = list(parser.parse(source, options.dict(), Bar('Processing')))
